"""Initial setup

Revision ID: 05cf60a0fd22
Revises: 7923ec94177a
Create Date: 2017-01-16 13:48:40.525749

"""

# revision identifiers, used by Alembic.
revision = '05cf60a0fd22'
down_revision = '7923ec94177a'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
